Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorStephen Swaney <sswaney@centurytel.net>2006-07-12 05:36:07 +0400
committerStephen Swaney <sswaney@centurytel.net>2006-07-12 05:36:07 +0400
commitfec1ebaca3bc4b15ce3dd50e85fce3a74d362420 (patch)
tree7765f34586920f20187182ce844f9311d1975286 /source
parent0d9002354f71c02ba0662c7a9fbe23e63e33cc88 (diff)
A little spell-checkage.
Some return types changed from PyNone ( a C name ) to None.
Diffstat (limited to 'source')
-rw-r--r--source/blender/python/api2_2x/doc/API_intro.py2
-rw-r--r--source/blender/python/api2_2x/doc/API_related.py16
-rw-r--r--source/blender/python/api2_2x/doc/Armature.py14
-rw-r--r--source/blender/python/api2_2x/doc/BGL.py34
-rw-r--r--source/blender/python/api2_2x/doc/BezTriple.py2
-rw-r--r--source/blender/python/api2_2x/doc/Blender.py6
-rw-r--r--source/blender/python/api2_2x/doc/Camera.py4
-rw-r--r--source/blender/python/api2_2x/doc/Constraint.py14
-rw-r--r--source/blender/python/api2_2x/doc/Curve.py78
-rw-r--r--source/blender/python/api2_2x/doc/Draw.py28
-rw-r--r--source/blender/python/api2_2x/doc/Effect.py86
-rw-r--r--source/blender/python/api2_2x/doc/Font.py4
-rw-r--r--source/blender/python/api2_2x/doc/Mesh.py10
-rw-r--r--source/blender/python/api2_2x/doc/Object.py138
14 files changed, 218 insertions, 218 deletions
diff --git a/source/blender/python/api2_2x/doc/API_intro.py b/source/blender/python/api2_2x/doc/API_intro.py
index e0f602a2c96..5b3c55bfbb7 100644
--- a/source/blender/python/api2_2x/doc/API_intro.py
+++ b/source/blender/python/api2_2x/doc/API_intro.py
@@ -180,7 +180,7 @@ The Game Engine API:
engine lets programmers add scripts to improve game AI, control, etc, making
more complex interaction and tricks possible. The game engine API is
separate from the Blender Python API this document references and you can
- find its own ref doc in the docs section of the main sites below.
+ find its own ref doc in the doc section of the main sites below.
Blender Data Structures:
------------------------
diff --git a/source/blender/python/api2_2x/doc/API_related.py b/source/blender/python/api2_2x/doc/API_related.py
index fb84569f601..87b29e7f524 100644
--- a/source/blender/python/api2_2x/doc/API_related.py
+++ b/source/blender/python/api2_2x/doc/API_related.py
@@ -103,7 +103,7 @@ Introduction:
# an animation in the script body itself, naturally.
The rendered pictures will be written to the default render folder, that can
- also be set via bpython (take a look at L{Render.RenderData}). Their
+ also be set via BPython (take a look at L{Render.RenderData}). Their
names will be the equivalent frame number followed by the extension of the
chosen image type: 0001.png, for example. To rename them to something else,
coders can use the C{rename} function in the standard 'os' Python module.
@@ -176,7 +176,7 @@ Introduction:
# done rendering, clean up
delete_my_very_detailed_mesh_data()
- As suggested by the example above, this is specially useful for script links
+ As suggested by the example above, this is especially useful for script links
that need to generate data only useful while rendering, or in case they need
to switch between two mesh data objects, one meant for realtime display and
the other, more detailed, for renders.
@@ -261,7 +261,7 @@ Introduction:
- DRAW handlers should leave the space in the same state it was before they
were executed. OpenGL attributes and the modelview and projection matrices
are automatically saved (pushed) before a DRAW handler runs and restored
- (poped) after it finishes, no need to worry about that. Draw handlers
+ (popped) after it finishes, no need to worry about that. Draw handlers
should not grab events;
- If script handlers need to pass information to each other (for example an
EVENT handler passing info to a DRAW handler), use the L{Registry} module.
@@ -273,13 +273,13 @@ Introduction:
====================
To be registered a script needs two things:
- - to be either in the default scripts dir or in the user defined scripts
+ - to be either in the default scripts directory or in the user defined scripts
path (see User Preferences window -> File Paths tab -> Python path);
- to have a proper header.
- Try 'blender -d' to know where your default dir for scripts is, it will
- inform either the dir or the file with that info already parsed, which is
- in the same dir of the scripts folder.
+ Try 'blender -d' to know where your default directory for scripts is, it will
+ inform either the directory or the file with that info already parsed, which is
+ in the same directory of the scripts folder.
The header should be like this one (all double and single apostrophes below
are required)::
@@ -495,7 +495,7 @@ Introduction:
This script should be available from the System menu in the Scripts window.
It provides a GUI to view and edit saved configuration data, both from the
Registry dictionary in memory and the scripts config data dir. This is
- useful for all scripts with config vars, but specially for those without GUI's,
+ useful for all scripts with config vars, but especially for those without GUIs,
like most importers and exporters, since this editor will provide one for them.
The example above already gives a good idea of how the information can be
diff --git a/source/blender/python/api2_2x/doc/Armature.py b/source/blender/python/api2_2x/doc/Armature.py
index 12d3f41495b..e94b03b3d9a 100644
--- a/source/blender/python/api2_2x/doc/Armature.py
+++ b/source/blender/python/api2_2x/doc/Armature.py
@@ -44,7 +44,7 @@ Example::
Example::
- # Adds emptys for every bone in the selected armature, an example of getting worldspace locations for bones.
+ # Adds empties for every bone in the selected armature, an example of getting worldspace locations for bones.
from Blender import *
def test_arm():
scn= Scene.GetCurrent()
@@ -131,7 +131,7 @@ class Armature:
@type envelopes: Bool
@ivar restPosition: Show rest position (no posing possible)
@type restPosition: Bool
- @ivar delayDeform: Dont deform children when manipulating bones
+ @ivar delayDeform: Don't deform children when manipulating bones
@type delayDeform: Bool
@ivar drawAxes: Draw bone axes
@type drawAxes: Bool
@@ -199,21 +199,21 @@ class BonesDict:
def items():
"""
- Retun the key, value pairs in this dictionary
+ Return the key, value pairs in this dictionary
@rtype: string, BPy_bone
@return: All strings, and py_bones in the armature (in that order)
"""
def keys():
"""
- Retun the keys in this dictionary
+ Return the keys in this dictionary
@rtype: string
@return: All strings representing the bone names
"""
def values():
"""
- Retun the values in this dictionary
+ Return the values in this dictionary
@rtype: BPy_bone
@return: All BPy_bones in this dictionary
"""
@@ -255,7 +255,7 @@ class Bone:
@ivar options: Various bone options which can be:
- Armature.CONNECTED: IK to parent
- Armature.HINGE: No parent rotation or scaling
- - Armature.NO_DEFORM: The bone does not deform geometetry
+ - Armature.NO_DEFORM: The bone does not deform geometry
- Armature.MULTIPLY: Multiply vgroups by envelope
- Armature.HIDDEN_EDIT: Hide bones in editmode
- Armature.ROOT_SELECTED: Selection of root ball of bone
@@ -312,7 +312,7 @@ class Editbone:
@ivar options: Various bone options which can be:
- Armature.CONNECTED: IK to parent
- Armature.HINGE: No parent rotation or scaling
- - Armature.NO_DEFORM: The bone does not deform geometetry
+ - Armature.NO_DEFORM: The bone does not deform geometry
- Armature.MULTIPLY: Multiply vgroups by envelope
- Armature.HIDDEN_EDIT: Hide bones in editmode
- Armature.ROOT_SELECTED: Selection of root ball of bone
diff --git a/source/blender/python/api2_2x/doc/BezTriple.py b/source/blender/python/api2_2x/doc/BezTriple.py
index 791e103c18f..2ac78bdcbec 100644
--- a/source/blender/python/api2_2x/doc/BezTriple.py
+++ b/source/blender/python/api2_2x/doc/BezTriple.py
@@ -12,7 +12,7 @@ CurNurb and IpoCurve objects.
@type HandleTypes: readonly dictionary
@var HandleTypes: The available BezTriple handle types.
- - FREE - handle has no constrints
+ - FREE - handle has no constraints
- AUTO - completely constrain handle based on knot position
- VECT - constraint handle to line between current and neighboring knot
- ALIGN - constrain handle to lie in a straight line with knot's other
diff --git a/source/blender/python/api2_2x/doc/Blender.py b/source/blender/python/api2_2x/doc/Blender.py
index dc6345debaa..eea61dad92d 100644
--- a/source/blender/python/api2_2x/doc/Blender.py
+++ b/source/blender/python/api2_2x/doc/Blender.py
@@ -75,7 +75,7 @@ def Get (request):
- 'endframe': the end frame of the animation.
- 'rt': the value of the 'rt' button for general debugging
- 'filename': the name of the last file read or written.
- - 'homedir': Blender's home dir.
+ - 'homedir': Blender's home directory.
- 'datadir' : the path to the dir where scripts should store and
retrieve their data files, including saved configuration (can
be None, if not found).
@@ -127,7 +127,7 @@ def Load (filename = None):
.B.blend file is loaded.
@warn: loading a new .blend file removes the current data in Blender. For
- safety, this function saves the current data as an autosave file in
+ safety, this function saves the current data as an auto-save file in
the temporary dir used by Blender before loading a new Blender file.
@warn: after a call to Load(blendfile), current data in Blender is lost,
including the Python dictionaries. Any posterior references in the
@@ -179,7 +179,7 @@ def Run (script):
def ShowHelp (script):
"""
Show help for the given script. This is a time-saver ("code-saver") for
- scripts that need to feature a 'help' button in their GUI's or a 'help'
+ scripts that need to feature a 'help' button in their GUIs or a 'help'
submenu option. With proper documentation strings, calling this function is
enough to present a screen with help information plus link and email buttons.
@type script: string
diff --git a/source/blender/python/api2_2x/doc/Camera.py b/source/blender/python/api2_2x/doc/Camera.py
index 57a4da9b18e..2c81c5b960e 100644
--- a/source/blender/python/api2_2x/doc/Camera.py
+++ b/source/blender/python/api2_2x/doc/Camera.py
@@ -51,7 +51,7 @@ class Camera:
This object gives access to Camera-specific data in Blender.
@ivar name: The Camera Data name.
@ivar type: The Camera type: 'persp':0 or 'ortho':1.
- @ivar mode: The mode flags: B{or'ed value}: 'showLimits':1, 'showMist':2.
+ @ivar mode: The mode flags: B{ORed value}: 'showLimits':1, 'showMist':2.
@ivar lens: The lens value in [1.0, 250.0], only relevant to *persp*
cameras.
@ivar scale: The scale value in [0.01, 1000.00], only relevant to *ortho*
@@ -118,7 +118,7 @@ class Camera:
Get this Camera's mode flags.
@rtype: int
@return: B{OR'ed value}: 'showLimits' is 1, 'showMist' is 2, or
- resp. 01 and 10 in binary.
+ respectively, 01 and 10 in binary.
"""
def setMode(mode1 = None, mode2 = None):
diff --git a/source/blender/python/api2_2x/doc/Constraint.py b/source/blender/python/api2_2x/doc/Constraint.py
index 5d84f97f5c2..ae5d61687ad 100644
--- a/source/blender/python/api2_2x/doc/Constraint.py
+++ b/source/blender/python/api2_2x/doc/Constraint.py
@@ -37,7 +37,7 @@ Or to print all the constraints attached to each bone in a pose::
@var Settings: Constant dict used for changing constraint settings.
- Used for all constraints
- TARGET (Object)
- - BONE (string): name of Bone subtarget (for armature targets) (Note: not
+ - BONE (string): name of Bone sub-target (for armature targets) (Note: not
used by Stretch To (STRETCHTO))
- Used by IK Solver (IKSOLVER) constraint:
- TOLERANCE (float): clamped to [0.0001:1.0]
@@ -126,7 +126,7 @@ class Constraints:
"""
Remove a constraint from this objects constraint sequence.
@param con: a constraint from this sequence to remove.
- @type con: Constriant
+ @type con: Constraint
@note: Accessing attributes of the constraint after it is removed will
throw an exception.
"""
@@ -135,16 +135,16 @@ class Constraints:
"""
Moves the constraint up in the object's constraint stack.
@param con: a constraint from this sequence to remove.
- @type con: Constriant
- @rtype: PyNone
+ @type con: Constraint
+ @rtype: None
"""
def moveDown(con):
"""
Moves the constraint down in the object's constraint stack.
@param con: a constraint from this sequence to remove.
- @type con: Constriant
- @rtype: PyNone
+ @type con: Constraint
+ @rtype: None
"""
class Constraint:
@@ -184,7 +184,7 @@ class Constraint:
def insertKey(frame):
"""
Adds an influence keyframe for the constraint Ipo.
- @rtype: PyNone
+ @rtype: None
@param frame: the frame number at which to insert the key.
@type frame: float
"""
diff --git a/source/blender/python/api2_2x/doc/Curve.py b/source/blender/python/api2_2x/doc/Curve.py
index 2397f60b67c..ee8a5bfb3a1 100644
--- a/source/blender/python/api2_2x/doc/Curve.py
+++ b/source/blender/python/api2_2x/doc/Curve.py
@@ -88,7 +88,7 @@ class Curve:
@ivar size: The Curve Data size(from the center).
@type size: list of 3 floats
@ivar bevob: The Curve Bevel Object
- @type bevob: Blender L{Object<Object.Object>} or PyNone
+ @type bevob: Blender L{Object<Object.Object>} or None
@ivar key: The Key object associated with this Curve, if any.
@type key: Blender L{Key<Key.Key>}
"""
@@ -102,7 +102,7 @@ class Curve:
def setName(name):
"""
Set the name of this Curve Data object.
- @rtype: PyNone
+ @rtype: None
@type name: string
@param name: The new name.
"""
@@ -117,7 +117,7 @@ class Curve:
def setPathLen(len):
"""
Set this Curve's path length.
- @rtype: PyNone
+ @rtype: None
@type len: int
@param len: the new curve's length.
"""
@@ -132,7 +132,7 @@ class Curve:
def setTotcol(totcol):
"""
Set the number of materials linked to the Curve.
- @rtype: PyNone
+ @rtype: None
@type totcol: int
@param totcol: number of materials linked.
"""
@@ -153,7 +153,7 @@ class Curve:
def setFlag(val):
"""
Set the Curve flag value. The flag corresponds to the Blender settings for 3D, Front, Back, CurvePath and CurveFollow. This parameter is a bitfield.
- @rtype: PyNone
+ @rtype: None
@type val: integer bitfield
@param val : The Curve's flag bits. See L{getFlag} for the meaning of the individual bits.
"""
@@ -167,7 +167,7 @@ class Curve:
def setBevresol(bevelresol):
"""
Set the Curve's bevel resolution value.
- @rtype: PyNone
+ @rtype: None
@type bevelresol: float
@param bevelresol: The new Curve's bevel resolution value.
"""
@@ -181,7 +181,7 @@ class Curve:
def setResolu(resolu):
"""
Set the Curve's U-resolution value.
- @rtype: PyNone
+ @rtype: None
@type resolu: float
@param resolu: The new Curve's U-resolution value.
"""
@@ -195,7 +195,7 @@ class Curve:
def setResolv(resolv):
"""
Set the Curve's V-resolution value.
- @rtype: PyNone
+ @rtype: None
@type resolv: float
@param resolv: The new Curve's V-resolution value.
"""
@@ -209,7 +209,7 @@ class Curve:
def setWidth(width):
"""
Set the Curve's width value.
- @rtype: PyNone
+ @rtype: None
@type width: float
@param width: The new Curve's width value.
"""
@@ -223,7 +223,7 @@ class Curve:
def setExt1(ext1):
"""
Set the Curve's ext1 value.
- @rtype: PyNone
+ @rtype: None
@type ext1: float
@param ext1: The new Curve's ext1 value.
"""
@@ -237,7 +237,7 @@ class Curve:
def setExt2(ext2):
"""
Set the Curve's ext2 value.
- @rtype: PyNone
+ @rtype: None
@type ext2: float
@param ext2: The new Curve's ext2 value.
"""
@@ -265,7 +265,7 @@ class Curve:
def setControlPoint( numcurve, numpoint, controlpoint):
"""
Set the Curve's controlpoint value. The numpoint arg is an index into the list of points and starts with 0.
- @rtype: PyNone
+ @rtype: None
@type numcurve: int
@type numpoint: int
@type controlpoint: list
@@ -279,13 +279,13 @@ class Curve:
"""
Add a new control point to the indicated curve (B{deprecated}).
New scripts should use L{CurNurb.append()}.
- @rtype: PyNone
+ @rtype: None
@type numcurve: int
@type new_control_point: list of floats or BezTriple
@param numcurve: index for spline in Curve, starting from 0
@param new_control_point: depends on curve's type.
- type Bezier: a BezTriple
- - type Nurb: a list of four or five floats for the xyzwt values
+ - type Nurb: a list of four or five floats for the xyzw values
@raise AttributeError: throws exception if numcurve is out of range.
"""
@@ -307,7 +307,7 @@ class Curve:
def setLoc(location):
"""
Set the curve's location value.
- @rtype: PyNone
+ @rtype: None
@type location: list[3]
@param location: The new Curve's location values.
"""
@@ -321,7 +321,7 @@ class Curve:
def setRot(rotation):
"""
Set the Curve's rotation value.
- @rtype: PyNone
+ @rtype: None
@type rotation: list[3]
@param rotation: The new Curve's rotation values.
"""
@@ -335,7 +335,7 @@ class Curve:
def setSize(size):
"""
Set the curve size value.
- @rtype: PyNone
+ @rtype: None
@type size: list[3]
@param size: The new Curve's size values.
"""
@@ -350,35 +350,35 @@ class Curve:
def getBevOb():
"""
Returns the Bevel Object (BevOb) assigned to the Curve.
- @rtype: Blender Object or PyNone
+ @rtype: Blender Object or None
@return: Bevel Object (BevOb) assigned to the Curve.
"""
def setBevOb( object ):
"""
Assign a Bevel Object (BevOb) to the Curve. Passing None as the object parameter removes the bevel.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
@type object: Curve type Blender Object
@param object: Blender Object to assign as Bevel Object (BevOb)
- @raise TypeError: throws exception if the parameter is not a Curve type Blender Object or PyNone
+ @raise TypeError: throws exception if the parameter is not a Curve type Blender Object or None
"""
def getTaperOb():
"""
Returns the Taper Object (TaperOb) assigned to the Curve.
- @rtype: Blender Object or PyNone
+ @rtype: Blender Object or None
@return: Taper Object (TaperOb) assigned to the Curve.
"""
def setTaperOb( object ):
"""
Assign a Taper Object (TaperOb) to the Curve. Passing None as the object parameter removes the taper.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
@type object: Curve type Blender Object
@param object: Blender Object to assign as Taper Object (TaperOb)
- @raise TypeError: throws exception if the parameter is not a Curve type Blender Object or PyNone
+ @raise TypeError: throws exception if the parameter is not a Curve type Blender Object or None
"""
def update():
@@ -386,8 +386,8 @@ class Curve:
Updates display list for a Curve.
Used after making changes to control points.
You B{must} use this if you want to see your changes!
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def isNurb( curve_num ):
@@ -458,8 +458,8 @@ class CurNurb:
def __setitem__( n, point ):
"""
Replace the Nth point in the curve. The type of the argument must match the type of the curve. List of 4 floats (optional 5th float is the tilt value in radians) for Nurbs or BezTriple for Bezier.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
@type n: integer
@param n: the index of the element to replace
@type point: BezTriple or list of 4 floats (optional 5th float is the tilt value in radians)
@@ -478,8 +478,8 @@ class CurNurb:
def append( new_point ):
"""
Appends a new point to a curve. This method appends points to both Bezier and Nurb curves. The type of the argument must match the type of the curve. List of 4 floats (optional 5th float is the tilt value in radians) for Nurbs or BezTriple for Bezier.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
@type new_point: BezTriple or list of 4 floats (optional 5th float is the tilt value in radians)
@param new_point: the new point to be appended to the curve. The new point can be either a BezTriple type or a list of 4 floats in x,y,z,w (optionally tilt in radians as 5th value) format for a Nurb curve.
"""
@@ -487,8 +487,8 @@ class CurNurb:
def setMatIndex( index ):
"""
Sets the Material index for this CurNurb.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
@type index: integer
@param index: the new value for the Material number of this CurNurb. No range checking is done.
"""
@@ -531,8 +531,8 @@ class CurNurb:
Bit 0 controls whether or not the curve is cyclic (1 = cyclic).
@type flag: integer
@param flag: CurNurb knot flag
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getFlagV():
@@ -547,8 +547,8 @@ class CurNurb:
Set the CurNurb knot flag V (knots are recalculated automatically).
@type value: integer
@param value: See L{setFlagU} for description of return.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getType():
@@ -563,6 +563,6 @@ class CurNurb:
Set the type of the curve and converts the curve to its new type if needed
@type value: integer
@param value: CurNurb type flag (0 - Poly, 1 - Bezier, 4 - NURBS)
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
diff --git a/source/blender/python/api2_2x/doc/Effect.py b/source/blender/python/api2_2x/doc/Effect.py
index 1086b6706f7..c8ff87385d7 100644
--- a/source/blender/python/api2_2x/doc/Effect.py
+++ b/source/blender/python/api2_2x/doc/Effect.py
@@ -3,7 +3,7 @@
"""
The Blender.Effect submodule
-B{new}: now L{Get}('objname') (without specifying second paramenter: 'position') returns a list of all effects linked to object "objname".
+B{new}: now L{Get}('objname') (without specifying second parameter: 'position') returns a list of all effects linked to object "objname".
Effect
======
@@ -182,8 +182,8 @@ class Effect:
Deprecated, since only particle effects are supported.
@type name: int
@param name : the new type.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getFlag():
@@ -200,8 +200,8 @@ class Effect:
Sets the flag of an effect object. See L{Flags} for values.
@type newflag: int
@param newflag: the new flag.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getStartTime():
@@ -216,8 +216,8 @@ class Effect:
Sets the starting time of an particle effect object
@type newstart: float
@param newstart: the new starting time.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getEndTime():
@@ -233,8 +233,8 @@ class Effect:
Sets the end time of an particle effect object
@type newendrt: float
@param newendrt: the new end time.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getLifetime():
@@ -250,8 +250,8 @@ class Effect:
Sets the lifetime of a particle effect object
@type newlifetime: float
@param newlifetime: the new lifetime.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getNormfac():
@@ -267,8 +267,8 @@ class Effect:
Sets the normal strength of the particles (relatively to mesh).
@type newnormfac: float
@param newnormfac: the normal strength of the particles (relatively to mesh).
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getObfac():
@@ -284,8 +284,8 @@ class Effect:
Sets the initial strength of the particles relatively to objects.
@type newobfac: float
@param newobfac: the initial strength of the particles relatively to objects.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getRandfac():
@@ -301,8 +301,8 @@ class Effect:
Sets the random strength applied to the particles.
@type newrandfac: float
@param newrandfac: the random strength applied to the particles.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getTexfac():
@@ -318,8 +318,8 @@ class Effect:
Sets the strength applied to the particles from the texture of the object.
@type newtexfac: float
@param newtexfac: the strength applied to the particles from the texture of the object.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getRandlife():
@@ -335,8 +335,8 @@ class Effect:
Sets the variability of the life of the particles.
@type newrandlife: float
@param newrandlife: the variability of the life of the particles.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getNabla():
@@ -352,8 +352,8 @@ class Effect:
Sets the sensibility of the particles to the variations of the texture.
@type newnabla: float
@param newnabla: the sensibility of the particles to the variations of the texture.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getVectsize():
@@ -369,8 +369,8 @@ class Effect:
Sets the size of the vector which is associated to the particles.
@type newvectsize: float
@param newvectsize: the size of the vector which is associated to the particles.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getTotpart():
@@ -386,8 +386,8 @@ class Effect:
Sets the the total number of particles.
@type newtotpart: int
@param newtotpart: the the total number of particles.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getTotkey():
@@ -402,8 +402,8 @@ class Effect:
Sets the number of keys associated to the particles.
@type newtotkey: int
@param newtotkey: number of keys associated to the particles.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getSeed():
@@ -418,8 +418,8 @@ class Effect:
Sets the random number generator seed.
@type newseed: int
@param newseed: new seed value.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getForce():
@@ -434,8 +434,8 @@ class Effect:
Sets the force applied to the particles.
@type newforce: tuple of 3 floats
@param newforce: force applied to the particles.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getMult():
@@ -450,8 +450,8 @@ class Effect:
Sets the probabilities of a particle having a child.
@type newmult: tuple of 4 floats
@param newmult: probabilities of a particle having a child.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getLife():
@@ -466,8 +466,8 @@ class Effect:
Sets the average life of the particles (4 generations).
@type newlife: tuple of 4 floats
@param newlife: average life of the particles (4 generations).
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getChild():
@@ -482,8 +482,8 @@ class Effect:
Sets the average number of children of the particles (4 generations).
@type newchild: tuple of 4 ints
@param newchild: average number of children of the particles (4 generations).
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getMat():
@@ -498,8 +498,8 @@ class Effect:
Sets the indexes of the materials associated to the particles (4 generations).
@type newmat: tuple of 4 ints
@param newmat: the indexes of the materials associated to the particles (4 generations).
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getDefvec():
@@ -515,8 +515,8 @@ class Effect:
@type newdefvec: tuple of 3 floats
@param newdefvec: the x, y and z components of the force defined by the
texture.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getParticlesLoc ( time ):
diff --git a/source/blender/python/api2_2x/doc/Font.py b/source/blender/python/api2_2x/doc/Font.py
index e1e164ec3a7..5dc8388fad5 100644
--- a/source/blender/python/api2_2x/doc/Font.py
+++ b/source/blender/python/api2_2x/doc/Font.py
@@ -64,7 +64,7 @@ class Font:
Set the name of this Text3d object.
@type name: string
@param name: The new name.
- @returns: PyNone
+ @returns: None
"""
def getText():
@@ -78,6 +78,6 @@ class Font:
Set the text string in this Text3d object
@type name: string
@param name: The new text string for this object.
- @returns: PyNone
+ @returns: None
"""
diff --git a/source/blender/python/api2_2x/doc/Mesh.py b/source/blender/python/api2_2x/doc/Mesh.py
index 9ec9052d22f..950aebd114d 100644
--- a/source/blender/python/api2_2x/doc/Mesh.py
+++ b/source/blender/python/api2_2x/doc/Mesh.py
@@ -82,7 +82,7 @@ done once.
- TILES - uses tiled image.
- TWOSIDE - two-sided face.
@var FaceTranspModes: The available face transparency modes. Note: these are
- enumerated values (enums), they can't be combined (and'ed, or'ed, etc) like a bit vector.
+ enumerated values (enums), they can't be combined (ANDed, ORed, etc) like a bit vector.
- SOLID - draw solid.
- ADD - add to background (halo).
- ALPHA - draw with transparency.
@@ -122,7 +122,7 @@ def Get(name=None):
@param name: The name of the mesh data object.
@rtype: Mesh
@return: If a name is given, it returns either the requested mesh or None.
- If no parameter is given, it returns all the meshs in the current scene.
+ If no parameter is given, it returns all the meshes in the current scene.
"""
def New(name='Mesh'):
@@ -186,7 +186,7 @@ class MVert:
@ivar no: The vertex's unit normal vector (x, y, z).
B{Note}: if vertex coordinates are changed, it may be necessary to use
L{Mesh.calcNormals()} to update the vertex normals.
- B{Note}: Vertex normals can be set, but arnt wrapped so modifying a normal
+ B{Note}: Vertex normals can be set, but are not wrapped so modifying a normal
vector will not effect the verts normal. The result is only visible
when faces have the smooth option enabled.
Example::
@@ -562,7 +562,7 @@ class MFace:
Getting this attribute throw an exception if the mesh does not have
UV faces; use L{Mesh.faceUV} to test.
@type uv: list of vectors (WRAPPED DATA)
- @ivar uvSel: The face's UV coordinates seletion state; a 1 indicates the
+ @ivar uvSel: The face's UV coordinates selection state; a 1 indicates the
vertex is selected. Each vertex has its own UV coordinate select state
(this is not the same as the vertex's edit mode selection state).
Setting this attribute will create UV faces if they do not exist.
@@ -679,7 +679,7 @@ class Mesh:
B{Note}: L{Object.colbits<Object.Object.colbits>} needs to be set correctly
for each object in order for these materials to be used instead of
the object's materials.
- B{Note}: Making the material list shorter does not change the faces material indicies,
+ B{Note}: Making the material list shorter does not change the faces material indices,
take care when using the faces material indices to reference a material in the materials list.
B{Note}: The the list thats returned is not linked to the original mesh.
mesh.materials.append(material) wont do anything.
diff --git a/source/blender/python/api2_2x/doc/BGL.py b/source/blender/python/api2_2x/doc/BGL.py
index 75bffd86605..26bbfe0def6 100644
--- a/source/blender/python/api2_2x/doc/BGL.py
+++ b/source/blender/python/api2_2x/doc/BGL.py
@@ -74,7 +74,7 @@ Example::
#
Draw.Register(show_win, ev, None) # start the main loop
-@note: you can use the L{Image} module and L{Image.Image} bpy object to load
+@note: you can use the L{Image} module and L{Image.Image} BPy object to load
and set textures. See L{Image.Image.glLoad} and L{Image.Image.glFree},
for example.
@see: U{www.opengl.org}
@@ -130,7 +130,7 @@ def glBegin(mode):
def glBindTexture(target, texture):
"""
- Bind a named texture to a textureing target
+ Bind a named texture to a texturing target
@see: U{www.opengl.org/documentation/specs/man_pages/hardcopy/GL/html/gl/bindtexture.html}
@type target: Enumerated constant
@@ -148,7 +148,7 @@ def glBitmap(width, height, xorig, yorig, xmove, ymove, bitmap):
@param width, height: Specify the pixel width and height of the bitmap image.
@type xorig,yorig: float
@param xorig,yorig: Specify the location of the origin in the bitmap image. The origin is measured
- from the lower left corner of the bitmap, with right and up beigng the positive axes.
+ from the lower left corner of the bitmap, with right and up being the positive axes.
@type xmove,ymove: float
@param xmove,ymove: Specify the x and y offsets to be added to the current raster position after
the bitmap is drawn.
@@ -253,7 +253,7 @@ def glClearStencil(s):
def glClipPlane (plane, equation):
"""
- Specify a plane against which all geometery is clipped
+ Specify a plane against which all geometry is clipped
@see: U{www.opengl.org/documentation/specs/man_pages/hardcopy/GL/html/gl/clipplane.html}
@type plane: Enumerated constant
@@ -333,7 +333,7 @@ def glDeleteLists(list, range):
@see: U{www.opengl.org/documentation/specs/man_pages/hardcopy/GL/html/gl/deletelists.html}
@type list: unsigned int
- @param list: Specifiex the integer name of the first display list to delete
+ @param list: Specifies the integer name of the first display list to delete
@type range: int
@param range: Specifies the number of display lists to delete
"""
@@ -344,7 +344,7 @@ def glDeleteTextures(n, textures):
@see: U{www.opengl.org/documentation/specs/man_pages/hardcopy/GL/html/gl/deletetextures.html}
@type n: int
- @param n: Specifes the number of textures to be deleted
+ @param n: Specifies the number of textures to be deleted
@type textures: Buffer I{GL_INT}
@param textures: Specifies an array of textures to be deleted
"""
@@ -420,7 +420,7 @@ def glEdgeFlag (flag):
"""
B{glEdgeFlag, glEdgeFlagv}
- Flag edges as either boundary or nonboundary
+ Flag edges as either boundary or non-boundary
@see: U{www.opengl.org/documentation/specs/man_pages/hardcopy/GL/html/gl/edgeflag.html}
@type flag: Depends of function prototype
@@ -685,7 +685,7 @@ def glGetPolygonStipple(mask):
def glGetString(name):
"""
- Return a strin describing the current GL connection
+ Return a string describing the current GL connection
@see: U{www.opengl.org/documentation/specs/man_pages/hardcopy/GL/html/gl/getstring.html}
@type name: Enumerated constant
@@ -971,12 +971,12 @@ def glMap2 (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points):
@param target: Specifies the kind of values that are generated by the evaluator.
@type u1, u2: Depends on function prototype.
@param u1,u2: Specify a linear mapping of u, as presented to glEvalCoord2, to ^, t
- he variable that is evaluated by the equations specified by this command. Initally
+ he variable that is evaluated by the equations specified by this command. Initially
u1 is 0 and u2 is 1.
@type ustride: int
@param ustride: Specifies the number of floats or float (double)s between the beginning
of control point R and the beginning of control point R ij, where i and j are the u
- and v control pointiindices, respectively. This allows control points to be embedded
+ and v control point indices, respectively. This allows control points to be embedded
in arbitrary data structures. The only constraint is that the values for a particular
control point must occupy contiguous memory locations. The initial value of ustride is 0.
@type uorder: int
@@ -1279,9 +1279,9 @@ def glRasterPos (x,y,z,w):
raster position. If function prototype ends in 'v' specifies a pointer to an array of two,
three, or four elements, specifying x, y, z, and w coordinates, respectively.
@note:
- If you are drawing to the 3d view with a Scriptlink of a space handeler
+ If you are drawing to the 3d view with a Scriptlink of a space handler
the zoom level of the panels will scale the glRasterPos by the view matrix.
- so a X of 10 will not always offset 10 pixels as youd expect.
+ so a X of 10 will not always offset 10 pixels as you would expect.
To work around this get the scale value of the view matrix and use it to scale your pixel values.
@@ -1294,7 +1294,7 @@ def glRasterPos (x,y,z,w):
viewMatrix = Buffer(GL_FLOAT, 16)
glGetFloatv(GL_MODELVIEW_MATRIX, viewMatrix)
f = 1/viewMatrix[0]
- glRasterPos2f(xval*f, yval*f) # Instead of the useual glRasterPos2i(xval, yval)
+ glRasterPos2f(xval*f, yval*f) # Instead of the usual glRasterPos2i(xval, yval)
"""
def glReadBuffer(mode):
@@ -1553,7 +1553,7 @@ def glTexImage2D(target, level, internalformat, width, height, border, format, t
some integer n. All implementations support texture images that are at least 64
texels wide.
@type height: int
- @param height: Specifies the hieght of the texture image. Must be 2m+2(border) for
+ @param height: Specifies the height of the texture image. Must be 2m+2(border) for
some integer m. All implementations support texture images that are at least 64
texels high.
@type border: int
@@ -1716,7 +1716,7 @@ def gluUnProject(winx, winy, winz, modelMatrix, projMatrix, viewport, objx, objy
class Buffer:
"""
The Buffer object is simply a block of memory that is delineated and initialized by the
- user. Many OpenGL funtions return data to a C-style pointer, however, because this
+ user. Many OpenGL functions return data to a C-style pointer, however, because this
is not possible in python the Buffer object can be used to this end. Wherever pointer
notation is used in the OpenGL functions the Buffer object can be used in it's BGL
wrapper. In some instances the Buffer object will need to be initialized with the template
@@ -1752,8 +1752,8 @@ class Buffer:
be created for the buffer. If a sequence is passed for the dimensions, the buffer
becomes n-Dimensional, where n is equal to the number of parameters passed in the
sequence. Example: [256,2] is a two- dimensional buffer while [256,256,4] creates
- a three- dimensional buffer. You can think of each additional dimension as a subitem
- of the dimension to the left. i.e. [10,2] is a 10 element array each with 2 subitems.
+ a three- dimensional buffer. You can think of each additional dimension as a sub-item
+ of the dimension to the left. i.e. [10,2] is a 10 element array each with 2 sub-items.
[(0,0), (0,1), (1,0), (1,1), (2,0), ...] etc.
@type template: A python sequence object (optional)
@param template: A sequence of matching dimensions which will be used to initialize
diff --git a/source/blender/python/api2_2x/doc/Draw.py b/source/blender/python/api2_2x/doc/Draw.py
index faf97ec5e9a..9bfdb8b16fe 100644
--- a/source/blender/python/api2_2x/doc/Draw.py
+++ b/source/blender/python/api2_2x/doc/Draw.py
@@ -326,7 +326,7 @@ def PupIntInput(text, default, min, max):
"""
Create an integer number input pop-up.
This allows python to use Blender's integer number popup input.
Example::
default = 50
@@ -341,13 +341,13 @@ def PupIntInput(text, default, min, max):
print 'no user input'
@type text: string
- @param text: The text that is displayed in the popup.
+ @param text: The text that is displayed in the pop-up.
@type default: int
- @param default: The value that the popup is set to initially.
+ @param default: The value that the pop-up is set to initially.
@type min: int
- @param min: The lowest value the popup will allow.
+ @param min: The lowest value the pop-up will allow.
@type max: int
- @param max: The highest value the popup will allow.
+ @param max: The highest value the pop-up will allow.
@rtype: int
@return: the number chosen or None if none was chosen.
"""
@@ -356,7 +356,7 @@ def PupFloatInput(text, default, min, max, clickStep, floatLen):
"""
Create a floating point number input pop-up.
This allows python to use Blender's floating point popup input.
Example::
default = 50
@@ -373,13 +373,13 @@ def PupFloatInput(text, default, min, max, clickStep, floatLen):
print 'no user input'
@type text: string
- @param text: The text that is displayed in the popup.
+ @param text: The text that is displayed in the pop-up.
@type default: float
- @param default: The value that the popup is set to initially.
+ @param default: The value that the pop-up is set to initially.
@type min: float
- @param min: The lowest value the popup will allow.
+ @param min: The lowest value the pop-up will allow.
@type max: float
- @param max: The highest value the popup will allow.
+ @param max: The highest value the pop-up will allow.
@type clickStep: int
@param clickStep: How much is incremented per user click, 100 will increment 1.0, 10 will increment 0.1 etc.
@type floatLen: int
@@ -392,18 +392,18 @@ def PupStrInput(text, default, max = 20):
"""
Create a string input pop-up.
This allows python to use Blender's string popup input.
Example::
Blender.Draw.PupStrInput("Name:", "untitled", 25)
@type text: string
- @param text: The text that is displayed in the popup.
+ @param text: The text that is displayed in the pop-up.
@type default: string
- @param default: The value that the popup is set to initially. If it's longer
+ @param default: The value that the pop-up is set to initially. If it's longer
then 'max', it's truncated.
@type max: int
- @param max: The most characters the popup input will allow. If not given
+ @param max: The most characters the pop-up input will allow. If not given
it defaults to 20 chars. It should be in the range [1, 100].
@rtype: string
@return: The text entered by the user or None if none was chosen.
@@ -326,7 +326,7 @@ def PupIntInput(text, default, min, max):
"""
Create an integer number input pop-up.
- This allows python to use Blender's integer number popup input.
+ This allows python to use Blender's integer number pop-up input.
Example::
default = 50
@@ -356,7 +356,7 @@ def PupFloatInput(text, default, min, max, clickStep, floatLen):
"""
Create a floating point number input pop-up.
- This allows python to use Blender's floating point popup input.
+ This allows python to use Blender's floating point pop-up input.
Example::
default = 50
@@ -392,18 +392,18 @@ def PupStrInput(text, default, max = 20):
"""
Create a string input pop-up.
- This allows python to use Blender's string popup input.
+ This allows python to use Blender's string pop-up input.
Example::
Blender.Draw.PupStrInput("Name:", "untitled", 25)
diff --git a/source/blender/python/api2_2x/doc/Object.py b/source/blender/python/api2_2x/doc/Object.py
index 6eb36972ae7..2de7c5ca605 100644
--- a/source/blender/python/api2_2x/doc/Object.py
+++ b/source/blender/python/api2_2x/doc/Object.py
@@ -43,7 +43,7 @@ def New (type, name='type'):
@type name: string
@param name: The name of the object. By default, the name will be the same
as the object type.
- If the name is alredy in use, this new object will have a number at the end of the name.
+ If the name is already in use, this new object will have a number at the end of the name.
@return: The created Object.
I{B{Example:}}
@@ -170,7 +170,7 @@ class Object:
When dealing with properties and functions such as LocX/RotY/getLocation(), getSize() and getEuler()
Keep in mind that these transformation properties are relative to the objects parent (if any).
- To get these values in worldspace (taking into acount vertex parents, constraints etc)
+ To get these values in worldspace (taking into account vertex parents, constraints etc)
pass the argument 'worldspace' to these functions.
@ivar LocX: The X location coordinate of the object.
@@ -270,7 +270,7 @@ class Object:
@type protectFlags: int
@ivar DupGroup: The DupliGroup Animation Property.
Assign a group to DupGroup to make this object an instance of that group.
- This does not enable or disable the dupliGroup option, for that use
+ This does not enable or disable the DupliGroup option, for that use
getDupliGroup and setDupliGroup.
The dupliGroup is None when this object does not have a dupliGroup.
(Use with L{enableDupGroup<enableDupGroup>})
@@ -319,7 +319,7 @@ class Object:
@type DupSta: int
@ivar DupEnd: The DupliFrame end frame. (Use with L{enableDupFrames<enableDupFrames>})
@type DupEnd: int
- @ivar DupOn: The DupliFrames in sucsession between DupOff frames.
+ @ivar DupOn: The DupliFrames in succession between DupOff frames.
(Use with L{enableDupFrames<enableDupFrames>} and L{DupOff<DupOff>} > 0)
@type DupOn: int
@ivar DupOff: The DupliFrame removal of every Nth frame for this object. (Use with L{enableDupFrames<enableDupFrames>})
@@ -675,7 +675,7 @@ class Object:
@type objects: Sequence of Blender Object
@param objects: A list of objects matching the objects type.
@note: Objects in the list will not be removed from the scene,
- to avoid overlapping data you may want to remove them manualy after joining.
+ to avoid overlapping data you may want to remove them manually after joining.
@note: Join modifies the base objects data in place so that
other objects are joined into it. no new object or data is created.
@note: Join will only work for object types Mesh, Armature, Curve and Surface,
@@ -686,7 +686,7 @@ class Object:
@note: An error in the join function input will raise a TypeError,
otherwise an error in the data input will raise a RuntimeError,
for situations where you don't have tight control on the data that is being joined,
- you should handel the RuntimeError error, litting the user know the data cant be joined.
+ you should handle the RuntimeError error, letting the user know the data cant be joined.
This an happen if the data is too large or one of the objects data has a shape key.
"""
@@ -845,7 +845,7 @@ class Object:
if self and the object specified are of the same type.
@type object: Blender Object
@param object: A Blender Object of the same type.
- @note: This funtion is faster then using getData() and setData()
+ @note: This function is faster then using getData() and setData()
because it skips making a python object from the objects data.
"""
@@ -1018,7 +1018,7 @@ class Object:
"""
Set the the Object's Particle Interaction Strength.
Values between -1000.0 to 1000.0
- @rtype: PyNone
+ @rtype: None
@type strength: float
@param strength: the Object's Particle Interaction New Strength.
"""
@@ -1033,7 +1033,7 @@ class Object:
"""
Set the the Object's Particle Interaction falloff.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type falloff: float
@param falloff: the Object's Particle Interaction New falloff.
"""
@@ -1048,7 +1048,7 @@ class Object:
"""
Set the the Object's Particle Interaction MaxDist.
Values between 0 to 1000.0
- @rtype: PyNone
+ @rtype: None
@type MaxDist: float
@param MaxDist: the Object's Particle Interaction New MaxDist.
"""
@@ -1068,7 +1068,7 @@ class Object:
- FORCE
- VORTEX
- MAGNET
- @rtype: PyNone
+ @rtype: None
@type type: int
@param type: the Object's Particle Interaction Type.
"""
@@ -1083,7 +1083,7 @@ class Object:
"""
Set the the Object's Particle Interaction MaxDist.
0 = Off, 1 = on
- @rtype: PyNone
+ @rtype: None
@type status: int
@param status: the new status
"""
@@ -1098,7 +1098,7 @@ class Object:
"""
Set the the Object's Particle Interaction Deflection Setting.
0 = Off, 1 = on
- @rtype: PyNone
+ @rtype: None
@type status: int
@param status: the new status
"""
@@ -1113,7 +1113,7 @@ class Object:
"""
Set the the Object's Particle Interaction Permeability.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type perm: float
@param perm: the Object's Particle Interaction New Permeability.
"""
@@ -1128,7 +1128,7 @@ class Object:
"""
Set the the Object's Particle Interaction RandomDamp.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type damp: float
@param damp: the Object's Particle Interaction New RandomDamp.
"""
@@ -1143,179 +1143,179 @@ class Object:
"""
Set the the Object's Particle Interaction SurfaceDamp.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type damp: float
@param damp: the Object's Particle Interaction New SurfaceDamp.
"""
def getSBMass():
"""
- Get the Object's SB Mass.
+ Get the Object's SoftBody Mass.
@rtype: float
"""
def setSBMass(mass):
"""
- Set the the Object's SB Mass.
+ Set the the Object's SoftBody Mass.
Values between 0 to 50.0
- @rtype: PyNone
+ @rtype: None
@type mass: float
- @param mass: the Object's SB New mass.
+ @param mass: the Object's SoftBody New mass.
"""
def getSBGravity():
"""
- Get the Object's SB Gravity.
+ Get the Object's SoftBody Gravity.
@rtype: float
"""
def setSBGravity(grav):
"""
- Set the the Object's SB Gravity.
+ Set the the Object's SoftBody Gravity.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type grav: float
- @param grav: the Object's SB New Gravity.
+ @param grav: the Object's SoftBody New Gravity.
"""
def getSBFriction():
"""
- Get the Object's SB Friction.
+ Get the Object's SoftBody Friction.
@rtype: float
"""
def setSBFriction(frict):
"""
- Set the the Object's SB Friction.
+ Set the the Object's SoftBody Friction.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type frict: float
- @param frict: the Object's SB New Friction.
+ @param frict: the Object's SoftBody New Friction.
"""
def getSBErrorLimit():
"""
Get the Object's SB ErrorLimit.
@rtype: float
"""
def setSBErrorLimit(err):
"""
Set the the Object's SB ErrorLimit.
Values between 0 to 1.0
- @rtype: PyNone
+ @rtype: None
@type err: float
- @param err: the Object's SB New ErrorLimit.
+ @param err: the Object's SoftBody New ErrorLimit.
"""
def getSBGoalSpring():
"""
Get the Object's SB GoalSpring.
@rtype: float
"""
def setSBGoalSpring(gs):
"""
Set the the Object's SB GoalSpring.
Values between 0 to 0.999
- @rtype: PyNone
+ @rtype: None
@type gs: float
- @param gs: the Object's SB New GoalSpring.
+ @param gs: the Object's SoftBody New GoalSpring.
"""
def getSBGoalFriction():
"""
Get the Object's SB GoalFriction.
@rtype: float
"""
def setSBGoalFriction(gf):
"""
Set the the Object's SB GoalFriction.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type gf: float
- @param gf: the Object's SB New GoalFriction.
+ @param gf: the Object's SoftBody New GoalFriction.
"""
def getSBMinGoal():
"""
Get the Object's SB MinGoal.
@rtype: float
"""
def setSBMinGoal(mg):
"""
Set the the Object's SB MinGoal.
Values between 0 to 1.0
- @rtype: PyNone
+ @rtype: None
@type mg: float
- @param mg: the Object's SB New MinGoal.
+ @param mg: the Object's SoftBody New MinGoal.
"""
def getSBMaxGoal():
"""
Get the Object's SB MaxGoal.
@rtype: float
"""
def setSBMaxGoal(mg):
"""
Set the the Object's SB MaxGoal.
Values between 0 to 1.0
- @rtype: PyNone
+ @rtype: None
@type mg: float
- @param mg: the Object's SB New MaxGoal.
+ @param mg: the Object's SoftBody New MaxGoal.
"""
def getSBInnerSpring():
"""
Get the Object's SB InnerSpring.
@rtype: float
"""
def setSBInnerSpring(sprr):
"""
Set the the Object's SB InnerSpring.
Values between 0 to 0.999
- @rtype: PyNone
+ @rtype: None
@type sprr: float
- @param sprr: the Object's SB New InnerSpring.
+ @param sprr: the Object's SoftBody New InnerSpring.
"""
def getSBInnerSpringFriction():
"""
Get the Object's SB InnerSpringFriction.
@rtype: float
"""
def setSBInnerSpringFriction(sprf):
"""
Set the the Object's SB InnerSpringFriction.
Values between 0 to 10.0
- @rtype: PyNone
+ @rtype: None
@type sprf: float
- @param sprf: the Object's SB New InnerSpringFriction.
+ @param sprf: the Object's SoftBody New InnerSpringFriction.
"""
def getSBDefaultGoal():
"""
Get the Object's SB DefaultGoal.
@rtype: float
"""
def setSBDefaultGoal(goal):
"""
Set the the Object's SB DefaultGoal.
Values between 0 to 1.0
- @rtype: PyNone
+ @rtype: None
@type goal: float
- @param goal: the Object's SB New DefaultGoal.
+ @param goal: the Object's SoftBody New DefaultGoal.
"""
def isSB():
"""
- Get if the Object's SB is Enabled.
+ Get if the Object's SoftBody is Enabled.
@rtype: int
"""
@@ -1330,9 +1330,9 @@ class Object:
Enable / Disable SoftBodies PostDef option
1: on
0: off
- @rtype: PyNone
+ @rtype: None
@type switch: int
- @param switch: the Object's SB New PostDef Value.
+ @param switch: the Object's SoftBody New PostDef Value.
"""
def getSBUseGoal():
@@ -1346,9 +1346,9 @@ class Object:
Enable / Disable SoftBodies UseGoal option
1: on
0: off
- @rtype: PyNone
+ @rtype: None
@type switch: int
- @param switch: the Object's SB New UseGoal Value.
+ @param switch: the Object's SoftBody New UseGoal Value.
"""
def getSBUseEdges():
"""
@@ -1361,9 +1361,9 @@ class Object:
Enable / Disable SoftBodies UseEdges option
1: on
0: off
- @rtype: PyNone
+ @rtype: None
@type switch: int
- @param switch: the Object's SB New UseEdges Value.
+ @param switch: the Object's SoftBody New UseEdges Value.
"""
def getSBStiffQuads():
@@ -1377,9 +1377,9 @@ class Object:
Enable / Disable SoftBodies StiffQuads option
1: on
0: off
- @rtype: PyNone
+ @rtype: None
@type switch: int
- @param switch: the Object's SB New StiffQuads Value.
+ @param switch: the Object's SoftBody New StiffQuads Value.
"""
@@ -1143,179 +1143,179 @@ class Object:
def getSBErrorLimit():
"""
- Get the Object's SB ErrorLimit.
+ Get the Object's SoftBody ErrorLimit.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBErrorLimit(err):
"""
- Set the the Object's SB ErrorLimit.
+ Set the the Object's SoftBody ErrorLimit.
Values between 0 to 1.0
@@ -1143,179 +1143,179 @@ class Object:
def getSBGoalSpring():
"""
- Get the Object's SB GoalSpring.
+ Get the Object's SoftBody GoalSpring.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBGoalSpring(gs):
"""
- Set the the Object's SB GoalSpring.
+ Set the the Object's SoftBody GoalSpring.
Values between 0 to 0.999
@@ -1143,179 +1143,179 @@ class Object:
def getSBGoalFriction():
"""
- Get the Object's SB GoalFriction.
+ Get the Object's SoftBody GoalFriction.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBGoalFriction(gf):
"""
- Set the the Object's SB GoalFriction.
+ Set the the Object's SoftBody GoalFriction.
Values between 0 to 10.0
@@ -1143,179 +1143,179 @@ class Object:
def getSBMinGoal():
"""
- Get the Object's SB MinGoal.
+ Get the Object's SoftBody MinGoal.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBMinGoal(mg):
"""
- Set the the Object's SB MinGoal.
+ Set the the Object's SoftBody MinGoal.
Values between 0 to 1.0
@@ -1143,179 +1143,179 @@ class Object:
def getSBMaxGoal():
"""
- Get the Object's SB MaxGoal.
+ Get the Object's SoftBody MaxGoal.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBMaxGoal(mg):
"""
- Set the the Object's SB MaxGoal.
+ Set the the Object's SoftBody MaxGoal.
Values between 0 to 1.0
@@ -1143,179 +1143,179 @@ class Object:
def getSBInnerSpring():
"""
- Get the Object's SB InnerSpring.
+ Get the Object's SoftBody InnerSpring.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBInnerSpring(sprr):
"""
- Set the the Object's SB InnerSpring.
+ Set the the Object's SoftBody InnerSpring.
Values between 0 to 0.999
@@ -1143,179 +1143,179 @@ class Object:
def getSBInnerSpringFriction():
"""
- Get the Object's SB InnerSpringFriction.
+ Get the Object's SoftBody InnerSpringFriction.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBInnerSpringFriction(sprf):
"""
- Set the the Object's SB InnerSpringFriction.
+ Set the the Object's SoftBody InnerSpringFriction.
Values between 0 to 10.0
@@ -1143,179 +1143,179 @@ class Object:
def getSBDefaultGoal():
"""
- Get the Object's SB DefaultGoal.
+ Get the Object's SoftBody DefaultGoal.
"""
@@ -1143,179 +1143,179 @@ class Object:
def setSBDefaultGoal(goal):
"""
- Set the the Object's SB DefaultGoal.
+ Set the the Object's SoftBody DefaultGoal.
Values between 0 to 1.0